.. include:: ../README.rst


Documentation
-------------

.. toctree::
   :maxdepth: 3

   installation
   usage
   examples
   walkers
   The Sadie API <modules>
   contributing
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
